==> gvsbuild-2022.5.0-py3-none-any.whl: gvsbuild/projects/pango.py <==
#  Copyright (C) 2016 - Yevgen Muntyan
#  Copyright (C) 2016 - Ignacio Casal Quinteiro
#  Copyright (C) 2016 - Arnavion
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, see <http://www.gnu.org/licenses/>.

from gvsbuild.utils.base_builders import Meson
from gvsbuild.utils.base_expanders import Tarball
from gvsbuild.utils.base_project import Project, project_add


@project_add
class Pango(Tarball, Meson):
    def __init__(self):
        Project.__init__(
            self,
            "pango",
            archive_url="https://download.gnome.org/sources/pango/1.50/pango-1.50.11.tar.xz",
            hash="8800f812d89ee61388188703203f3a7878963c22f8695aaf1fa0a1a1428d17ae",
            dependencies=[
                "ninja",
                "meson",
                "cairo",
                "harfbuzz",
                "fribidi",
            ],
        )
        if self.opts.enable_gi:
            self.add_dependency("gobject-introspection")
            enable_gi = "enabled"
        else:
            enable_gi = "disabled"

        self.add_param(f"-Dintrospection={enable_gi}")

    def build(self):
        Meson.build(self)
        self.install(r"COPYING share\doc\pango")

==> gvsbuild-2023.10.0-py3-none-any.whl: gvsbuild/projects/pango.py <==
#  Copyright (C) 2016 The Gvsbuild Authors
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, see <http://www.gnu.org/licenses/>.

from gvsbuild.utils.base_builders import Meson
from gvsbuild.utils.base_expanders import Tarball
from gvsbuild.utils.base_project import Project, project_add


@project_add
class Pango(Tarball, Meson):
    def __init__(self):
        Project.__init__(
            self,
            "pango",
            version="1.50.14",
            lastversion_even=True,
            repository="https://gitlab.gnome.org/GNOME/pango",
            archive_url="https://download.gnome.org/sources/pango/{major}.{minor}/pango-{version}.tar.xz",
            hash="1d67f205bfc318c27a29cfdfb6828568df566795df0cb51d2189cde7f2d581e8",
            dependencies=[
                "ninja",
                "meson",
                "cairo",
                "harfbuzz",
                "fribidi",
            ],
        )
        if self.opts.enable_gi:
            self.add_dependency("gobject-introspection")
            enable_gi = "enabled"
        else:
            enable_gi = "disabled"

        self.add_param(f"-Dintrospection={enable_gi}")

    def build(self):
        Meson.build(self)
        self.install(r"COPYING share\doc\pango")
